gnunet-svn
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[libmicrohttpd] 26/31: tls_test_common: fixed comments and error message


From: gnunet
Subject: [libmicrohttpd] 26/31: tls_test_common: fixed comments and error messages
Date: Mon, 10 Oct 2022 13:01:11 +0200

This is an automated email from the git hooks/post-receive script.

karlson2k pushed a commit to branch master
in repository libmicrohttpd.

commit 749a8b434cdad1af2ff0aa1236cab59bbbac3642
Author: Evgeny Grin (Karlson2k) <k2k@narod.ru>
AuthorDate: Mon Oct 10 09:00:16 2022 +0300

    tls_test_common: fixed comments and error messages
---
 src/testcurl/https/tls_test_common.c | 8 ++++----
 1 file changed, 4 insertions(+), 4 deletions(-)

diff --git a/src/testcurl/https/tls_test_common.c 
b/src/testcurl/https/tls_test_common.c
index fba9068a..d2c7b14e 100644
--- a/src/testcurl/https/tls_test_common.c
+++ b/src/testcurl/https/tls_test_common.c
@@ -146,7 +146,7 @@ test_daemon_get (void *cls,
 
   if (memcmp (cbc.buf, test_data, len) != 0)
   {
-    fprintf (stderr, "Error: local file & received file differ.\n");
+    fprintf (stderr, "Error: local data & received data differ.\n");
     free (cbc.buf);
     return 1;
   }
@@ -359,7 +359,7 @@ gen_test_uri (char *uri,
 
 
 /**
  * test HTTPS file transfer
  */
 unsigned int
 test_https_transfer (void *cls,
@@ -397,13 +397,13 @@ test_https_transfer (void *cls,
     goto cleanup;
   }
 
   /* compare test file & daemon response */
   if ( (len != strlen (test_data)) ||
        (memcmp (cbc.buf,
                 test_data,
                 len) != 0) )
   {
-    fprintf (stderr, "Error: local file & received file differ.\n");
+    fprintf (stderr, "Error: original data & received data differ.\n");
     ret = 1;
   }
 cleanup:
@@ -359,7 +359,7 @@ gen_test_uri (char *uri,
 
 /**
- * test HTTPS file transfer
+ * test HTTPS data transfer
  */
 unsigned int
@@ -397,13 +397,13 @@ test_https_transfer (void *cls,
   }
 
-  /* compare test file & daemon response */
+  /* compare test data & daemon response */
   if ( (len != strlen (test_data)) ||
        (memcmp (cbc.buf,

-- 
To stop receiving notification emails like this one, please contact
gnunet@gnunet.org.



reply via email to

[Prev in Thread] Current Thread [Next in Thread]